pub struct TrustedDealerBuilder<E>where
E: Curve,{ /* private fields */ }Expand description
Trusted dealer builder
Implementations
Sourceimpl<E> TrustedDealerBuilder<E>where
E: Curve,
impl<E> TrustedDealerBuilder<E>where
E: Curve,
Sourcepub fn new(n: u16) -> TrustedDealerBuilder<E>
pub fn new(n: u16) -> TrustedDealerBuilder<E>
Construct a trusted dealer builder
Takes amount of key shares n to be generated
Sourcepub fn set_threshold(self, t: Option<u16>) -> TrustedDealerBuilder<E>
pub fn set_threshold(self, t: Option<u16>) -> TrustedDealerBuilder<E>
Sets threshold value
If threshold is Some(_), resulting key shares will be generated
using t-out-of-n VSS scheme. If it’s None, trusted dealer will
generate additive key shares in n-out-ouf-n scheme.
Note that setting t=Some(n) is not the same as setting t=None.
Both produce n-out-of-n key shares, but t=Some(n) mocks threshold
key generation with threshold=n, t=None mock non-threshold key
generation.
Default: None
Sets shared secret key to be generated
Resulting key shares will share specified secret key.
Sourcepub fn hd_wallet(self, v: bool) -> TrustedDealerBuilder<E>
pub fn hd_wallet(self, v: bool) -> TrustedDealerBuilder<E>
Specifies that the key being generated shall support HD derivation
Generates CoreKeyShares
For Shamir secret sharing, it’s shared at points 1 to n
Returns error if provided inputs are invalid, or if internal error has occurred.
Generates CoreKeyShares shared at random points
For Shamir secret sharing, the points at which the value is shared at
are chosen at random between 1 and u16::MAX. For additive shares,
this is the same as TrustedDealerBuilder::generate_shares
Returns error if provided inputs are invalid, or if internal error has occurred.
Generates CoreKeyShares shared at preimages provided. Each share is
going to have the given preimages as its I component.
Preimages are ignored for additive key shares.
Returns error if provided inputs are invalid, or if internal error has occurred.